@@ -1,7 +1,7 @@
 from pysrt.srttime import SubRipTime
 from pysrt.srtitem import SubRipItem
-from pysrt.srtfile import SubRipFile
+from pysrt.srtfile import SubRipFile, SUPPORT_UTF_32_LE, SUPPORT_UTF_32_BE
 from pysrt.srtexc import Error, InvalidItem, InvalidTimeString
 
-VERSION = (0, 4, 2)
+VERSION = (0, 4, 3)
 VERSION_STRING = '.'.join(str(i) for i in VERSION)
