@@ -9,11 +9,26 @@ from copy import copy
 from pysrt.srtexc import Error
 from pysrt.srtitem import SubRipItem
 
-BOMS = ((codecs.BOM_UTF32_LE, 'utf_32_le'),
-        (codecs.BOM_UTF32_BE, 'utf_32_be'),
-        (codecs.BOM_UTF16_LE, 'utf_16_le'),
+BOMS = [(codecs.BOM_UTF16_LE, 'utf_16_le'),
         (codecs.BOM_UTF16_BE, 'utf_16_be'),
-        (codecs.BOM_UTF8, 'utf_8'))
+        (codecs.BOM_UTF8, 'utf_8')]
+
+SUPPORT_UTF_32_LE = True
+try:
+    codecs.lookup('utf_32_le')
+except LookupError:
+    SUPPORT_UTF_32_LE = False
+else:
+    BOMS.insert(0, (codecs.BOM_UTF32_LE, 'utf_32_le'))
+
+SUPPORT_UTF_32_BE = True
+try:
+    codecs.lookup('utf_32_be')
+except LookupError:
+    SUPPORT_UTF_32_BE = False
+else:
+    BOMS.insert(0, (codecs.BOM_UTF32_BE, 'utf_32_be'))
+
 CODECS_BOMS = dict((codec, unicode(bom, codec)) for bom, codec in BOMS)
 BIGGER_BOM = max(len(bom) for bom, encoding in BOMS)
 
@@ -175,6 +190,16 @@ class SubRipFile(UserList, object):
             ...     print unicode(sub)
         """
         string_buffer = []
+
+        # weird bug workaround
+        if hasattr(source_file, 'seek'):
+            position = source_file.tell()
+            # under Python 2.5 this call return the second line of the file
+            # instead of the first character. It's probably a buffering bug
+            # in the codecs module. I've not found a better fix...
+            source_file.read(1)
+            source_file.seek(position)
+
         for index, line in enumerate(chain(source_file, u'\n')):
             if line.strip():
                 string_buffer.append(line)
@@ -245,7 +270,6 @@ class SubRipFile(UserList, object):
             return ''
         if hasattr(string_iterable, 'seek'):
             string_iterable.seek(previous_position)
-
         return first_line
 
     @classmethod
@@ -264,7 +288,7 @@ class SubRipFile(UserList, object):
     @classmethod
     def _open_unicode_file(cls, path, claimed_encoding=None):
         encoding = claimed_encoding or cls._detect_encoding(path)
-        source_file = codecs.open(path, 'rU', encoding=encoding)
+        source_file = codecs.open(path, 'r', encoding=encoding)
 
         # get rid of BOM if any
         possible_bom = CODECS_BOMS.get(encoding, None)
